@@ -4,8 +4,6 @@ library(ggplot2)
 
 test_that("things break in an expected way", {
 
-  testthat::skip_if_not_installed("rnaturalearthhires")
-
   expect_error({
     ggplot(iris, aes(Sepal.Length, Petal.Length)) +
         geom_point() +
@@ -61,7 +59,7 @@ test_that("things break in an expected way", {
         y = "Population density per square km") +
       theme_bw()
   },
-  "will be ignored")
+  "does not exist")
 
   my_grid <- us_state_grid1
 
