@@ -4,5 +4,5 @@ library(ggplot2)
 
 test_that("grids all load and work correctly", {
   for (grd in .valid_grids)
-    grid_preview(grd)
+    expect_no_error(prv <- grid_preview(grd, do_plot = FALSE))
 })
